@@ -65,7 +65,7 @@ class Fork(Base):
                 paramsInject = self.getParams(span, data, params)
 
                 # Ejecutar la funciona final
-                RESP = fnc(**paramsInject)
+                RESP = fnc(*paramsInject)
 
                 # Regresar la respuesta con el formato correcto
                 return self.formatResponse(data, RESP)
