@@ -18,7 +18,7 @@ class Worker(Base):
         """
         try:
             # Parametros
-            paramsInject = self.getParams(request, params)
+            paramsInject = self.getParams(span, request, params)
 
             # Ejecutar la funciona final
             RESP = fnc(*paramsInject)
