@@ -279,12 +279,18 @@ class Microservices(BaseClass, ABC):
         paramsConf = []
 
         # Recuperar el rootSpan
-        rootSpan = msg['metadata']['span'] if 'span' in msg['metadata'] else None
+        # msg['metadata']['span'] if 'span' in msg['metadata'] else None
+        rootSpan = None
 
         # Validar si es un smoktest
         if 'smoketest' in list(data):
-            span = self.___Tracer.start_span(
-                operation_name='smoketest', child_of=rootSpan)
+            span = None
+
+            if rootSpan is None:
+                span = self.___Tracer.start_span(operation_name='smoketest')
+            else:
+                span = self.___Tracer.start_span(
+                    operation_name='smoketest', child_of=rootSpan)
 
             span.set_tag(ext_tags.HTTP_METHOD, msg['metadata']['method'])
 
